.. Django Magic Notifier documentation master file, created by
   sphinx-quickstart on Mon Sep 20 01:43:15 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django Magic Notifier's documentation!
=================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   settings
   templates
   usage
   autoapi/index



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
